@@ -50,7 +50,9 @@ class BillingClient(AbstractClient):
 
 
     def CreateSavingPlanOrder(self, request):
-        """创建节省计划订单，创建订单完成需调用PayDeals接口完成订单支付
+        """接口迁移到其他业务
+
+        创建节省计划订单，创建订单完成需调用PayDeals接口完成订单支付
 
         :param request: Request instance for CreateSavingPlanOrder.
         :type request: :class:`tencentcloud.billing.v20180709.models.CreateSavingPlanOrderRequest`
@@ -325,6 +327,29 @@ class BillingClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def DescribeBillAdjustInfo(self, request):
+        """可以通过API获取当前UIN是否有调账，客户可以更快地主动地获取调账情况。
+
+        :param request: Request instance for DescribeBillAdjustInfo.
+        :type request: :class:`tencentcloud.billing.v20180709.models.DescribeBillAdjustInfoRequest`
+        :rtype: :class:`tencentcloud.billing.v20180709.models.DescribeBillAdjustInfoResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeBillAdjustInfo", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeBillAdjustInfoResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def DescribeBillDetail(self, request):
         """获取账单明细数据。
         注意事项：
@@ -631,6 +656,9 @@ class BillingClient(AbstractClient):
     def DescribeCostDetail(self, request):
         """查询消耗明细
 
+        注意事项：
+        1. 对于消耗明细数据量级很大（例如每月消耗明细量级超过100w）的客户，通过 API 调用明细数据会有超时风险，建议您开通消耗账单数据存储功能，通过存储桶中获取账单文件进行分析。[账单存储至COS桶](https://cloud.tencent.com/document/product/555/61275)
+
         :param request: Request instance for DescribeCostDetail.
         :type request: :class:`tencentcloud.billing.v20180709.models.DescribeCostDetailRequest`
         :rtype: :class:`tencentcloud.billing.v20180709.models.DescribeCostDetailResponse`
@@ -905,7 +933,9 @@ class BillingClient(AbstractClient):
 
 
     def DescribeSavingPlanOverview(self, request):
-        """查用当前用户明细节省计划总览查询时段内的使用情况
+        """接口迁移到其他业务
+
+        查用当前用户明细节省计划总览查询时段内的使用情况
 
         :param request: Request instance for DescribeSavingPlanOverview.
         :type request: :class:`tencentcloud.billing.v20180709.models.DescribeSavingPlanOverviewRequest`
@@ -951,7 +981,9 @@ class BillingClient(AbstractClient):
 
 
     def DescribeSavingPlanUsage(self, request):
-        """查用当前用户明细节省计划查询时段内的使用情况
+        """接口迁移到其他业务
+
+        查用当前用户明细节省计划查询时段内的使用情况
 
         :param request: Request instance for DescribeSavingPlanUsage.
         :type request: :class:`tencentcloud.billing.v20180709.models.DescribeSavingPlanUsageRequest`
